@@ -11,15 +11,18 @@
 #' @param na_values missing values (e.g. c(888, 999))
 #' @param na_range range of missing values (e.g. c(-9,-1))
 #' @param scale scale level (nominal, ordinal, scale)
+#' @param annotation additional information about variable
+#' @param wording question text
+#' @param subject subject
 #' @param ... further attributes passed to class
-.init <- function(x, label = NULL, labels = NULL, na_values = NULL, na_range = NULL, scale = NULL, ...) {
+.init <- function(x, label = NULL, labels = NULL, na_values = NULL, na_range = NULL, scale = NULL, annotation = NULL, wording = NULL, subject = NULL, ...) {
   UseMethod(".init")
 }
 
 
-.init.default <- function(x, label = NULL, labels = NULL, na_values = NULL, na_range = NULL, scale = NULL, ...) {
+.init.default <- function(x, label = NULL, labels = NULL, na_values = NULL, na_range = NULL, scale = NULL, annotation = NULL, wording = NULL, subject = NULL, ...) {
   # set class i_labelled
-  if(is.numeric(x) || is.factor(x)){
+  if(is.numeric(x) || is.factor(x) || is.logical(x)){
     structure(
       .Data = as.double(x),
       class = c("i_labelled", "double"),
@@ -28,6 +31,9 @@
       na_values = na_values,
       na_range = na_range,
       scale = scale,
+      annotation = annotation,
+      wording = wording,
+      subject = subject,
       ...
     )
   }else{
@@ -39,13 +45,16 @@
       na_values = na_values,
       na_range = na_range,
       scale = scale,
+      annotation = annotation,
+      wording = wording,
+      subject = subject,
       ...
     )
   }
 }
 
 
-.init.i_labelled <- function(x, label = NULL, labels = NULL, na_values = NULL, na_range = NULL, scale = NULL, ...) {
+.init.i_labelled <- function(x, label = NULL, labels = NULL, na_values = NULL, na_range = NULL, scale = NULL, annotation = NULL, wording = NULL, subject = NULL, ...) {
   # do nothing
   x
 }
