@@ -31,8 +31,6 @@ test_that("initialize class - errors", {
   ## value labels
   ### no duplicate values in value labels
   expect_error(i_labelled(1:3, labels = c(A = 1, B = 1)))
-  ### no duplicate labels in value labels
-  expect_error(i_labelled(1:3, labels = c(A = 1, A = 2)))
 })
 
 
